# Test Workflow

This reproduces an alternate project setup with all of the files (including test files) stored in the same directory. The test data are stored remotely as well which will test localization of the data for the workflow.

This also introduces WDL 1.0.
